@@ -3,13 +3,14 @@
 
 #' Paste strings together.
 #'
-#' Paste strings together. A wrapper of \code{paste0()}.
-#' Why \code{\%^\%}? Because typing \code{\%} and \code{^} is pretty easy by
-#' pressing \strong{Shift + 5 + 6 + 5}.
+#' Paste strings together. A wrapper of [`paste0()`][base::paste0].
+#' Why `%^%`? Because typing `%` and `^` is pretty easy by
+#' pressing **Shift + 5 + 6 + 5**.
 #'
 #' @param x,y Any objects, usually a numeric or character string or vector.
 #'
-#' @return A character string/vector of the pasted values.
+#' @return
+#' A character string/vector of the pasted values.
 #'
 #' @examples
 #' "He" %^% "llo"
@@ -22,113 +23,140 @@
 }
 
 
-#' The opposite of \code{\%in\%}.
+## The opposite of `%in%`.
+##
+## @param x Numeric or character vector.
+## @param vector Numeric or character vector.
+##
+## @return
+## A vector of `TRUE` or `FALSE`.
+##
+## @seealso
+## [`%in%`][base::match]
+##
+## @examples
+## data = data.table(ID=1:10, X=sample(1:10, 10))
+## data
+## data[ID %notin% c(1, 3, 5, 7, 9)]
+##
+## @export
+# `%notin%` = function(x, vector) {
+#   match(x, vector, nomatch=0L) == 0L
+# }
+
+
+#' @importFrom data.table %notin%
+#' @export
+data.table::`%notin%`
+
+
+#' A simple extension of `%in%`.
 #'
 #' @param x Numeric or character vector.
 #' @param vector Numeric or character vector.
 #'
-#' @return A vector of \code{TRUE} or \code{FALSE}.
+#' @return
+#' `TRUE` or `FALSE`.
 #'
-#' @examples
-#' data = data.table(ID=1:10, X=sample(1:10, 10))
-#' data
-#' data[ID %notin% c(1, 3, 5, 7, 9)]
+#' @seealso
+#' [`%in%`][base::match]
 #'
-#' @seealso \code{\link[base:match]{\%in\%}}
+#' [`%anyin%`]
 #'
-#' @export
-`%notin%` = function(x, vector) {
-  match(x, vector, nomatch=0L) == 0L
-}
-
-
-#' A simple extension of \code{\%in\%}.
+#' [`%nonein%`]
 #'
-#' @inheritParams %notin%
-#'
-#' @return \code{TRUE} or \code{FALSE}.
+#' [`%partin%`]
 #'
 #' @examples
 #' 1:2 %allin% 1:3  # TRUE
 #' 3:4 %allin% 1:3  # FALSE
 #'
-#' @seealso \code{\link[base:match]{\%in\%}},
-#' \code{\link{\%anyin\%}},
-#' \code{\link{\%nonein\%}},
-#' \code{\link{\%partin\%}}
-#'
 #' @export
 `%allin%` = function(x, vector) {
   all(x %in% vector)
 }
 
 
-#' A simple extension of \code{\%in\%}.
+#' A simple extension of `%in%`.
 #'
-#' @inheritParams %notin%
+#' @inheritParams %allin%
 #'
-#' @return \code{TRUE} or \code{FALSE}.
+#' @return
+#' `TRUE` or `FALSE`.
+#'
+#' @seealso
+#' [`%in%`][base::match]
+#'
+#' [`%allin%`]
+#'
+#' [`%nonein%`]
+#'
+#' [`%partin%`]
 #'
 #' @examples
 #' 3:4 %anyin% 1:3  # TRUE
 #' 4:5 %anyin% 1:3  # FALSE
 #'
-#' @seealso \code{\link[base:match]{\%in\%}},
-#' \code{\link{\%allin\%}},
-#' \code{\link{\%nonein\%}},
-#' \code{\link{\%partin\%}}
-#'
 #' @export
 `%anyin%` = function(x, vector) {
   any(x %in% vector)
 }
 
 
-#' A simple extension of \code{\%in\%}.
+#' A simple extension of `%in%`.
 #'
-#' @inheritParams %notin%
+#' @inheritParams %allin%
 #'
-#' @return \code{TRUE} or \code{FALSE}.
+#' @return
+#' `TRUE` or `FALSE`.
+#'
+#' @seealso
+#' [`%in%`][base::match]
+#'
+#' [`%allin%`]
+#'
+#' [`%anyin%`]
+#'
+#' [`%partin%`]
 #'
 #' @examples
 #' 3:4 %nonein% 1:3  # FALSE
 #' 4:5 %nonein% 1:3  # TRUE
 #'
-#' @seealso \code{\link[base:match]{\%in\%}},
-#' \code{\link{\%allin\%}},
-#' \code{\link{\%anyin\%}},
-#' \code{\link{\%partin\%}}
-#'
 #' @export
 `%nonein%` = function(x, vector) {
   !any(x %in% vector)
 }
 
 
-#' A simple extension of \code{\%in\%}.
+#' A simple extension of `%in%`.
 #'
-#' @param pattern Character string containing \strong{regular expressions} to be matched.
+#' @param pattern Character string containing **regular expressions** to be matched.
 #' @param vector Character vector.
 #'
-#' @return \code{TRUE} or \code{FALSE}.
+#' @return
+#' `TRUE` or `FALSE`.
+#'
+#' @seealso
+#' [`%in%`][base::match]
+#'
+#' [`%allin%`]
+#'
+#' [`%anyin%`]
+#'
+#' [`%nonein%`]
 #'
 #' @examples
 #' "Bei" %partin% c("Beijing", "Shanghai")  # TRUE
 #' "bei" %partin% c("Beijing", "Shanghai")  # FALSE
 #' "[aeiou]ng" %partin% c("Beijing", "Shanghai")  # TRUE
 #'
-#' @seealso \code{\link[base:match]{\%in\%}},
-#' \code{\link{\%allin\%}},
-#' \code{\link{\%anyin\%}},
-#' \code{\link{\%nonein\%}}
-#'
 #' @export
 `%partin%` = function(pattern, vector) {
   any(grepl(pattern, vector, perl=TRUE))
 }
 
 
-
 #### Basic Functions ####
 
 
@@ -141,17 +169,11 @@ installed = function(pkg) {
 #' Check dependencies of R packages.
 #'
 #' @param pkgs Package(s).
-#' @param excludes [Optional] Package(s) and their dependencies excluded from the dependencies of \code{pkgs}.
-#' Useful if you want to see the unique dependencies of \code{pkgs}.
+#' @param excludes \[Optional\] Package(s) and their dependencies excluded from the dependencies of `pkgs`.
+#' Useful if you want to see the unique dependencies of `pkgs`.
 #'
-#' @return A character vector of package names.
-#'
-## @examples
-## pkg_depend("jmv")
-## pkg_depend("dplyr", excludes="jmv")  # no unique dependencies
-## pkg_depend(pacman::p_depends("bruceR", local=TRUE)$Imports)
-##
-#' @seealso \code{\link{pkg_install_suggested}}
+#' @return
+#' A character vector of package names.
 #'
 #' @export
 pkg_depend = function(pkgs, excludes=NULL) {
@@ -174,21 +196,6 @@ pkg_depend = function(pkgs, excludes=NULL) {
 }
 
 
-#' Install suggested R packages.
-#'
-#' @param by Suggested by which package?
-#'
-#' @return No return value.
-#'
-#' @examples
-#' \dontrun{
-#'
-#' pkg_install_suggested()  # install all packages suggested by me
-#' }
-#'
-#' @seealso \code{\link{pkg_depend}}
-#'
-#' @export
 pkg_install_suggested = function(by) {
   if(missing(by)) {
     pkgs.suggests = "
@@ -242,14 +249,15 @@ pkg_install_suggested = function(by) {
 
 #' Print strings with rich formats and colors.
 #'
-#' @describeIn Print Paste and print strings.
+#' @describeIn Print
+#' Paste and print strings.
 #'
 #' @description
-#' Be frustrated with \code{print()} and \code{cat()}? Try \code{Print()}!
+#' Frustrated with [print()] and [cat()]? Try this!
 #' Run examples to see what it can do.
 #'
 #' @details
-#' Possible formats/colors that can be used in \code{"<< >>"} include:
+#' Possible formats/colors that can be used in `"<< >>"` include:
 #'
 #' (1) bold, italic, underline, reset, blurred, inverse, hidden, strikethrough;
 #'
@@ -257,17 +265,18 @@ pkg_install_suggested = function(by) {
 #'
 #' (3) bgBlack, bgWhite, bgRed, bgGreen, bgBlue, bgYellow, bgCyan, bgMagenta.
 #'
-#' See more details in \code{\link[glue:glue]{glue::glue()}} and \code{\link[glue:glue]{glue::glue_col()}}.
+#' See more details in [glue::glue()] and [glue::glue_col()].
 #'
-#' @param ... Character strings enclosed by \code{"{ }"} will be evaluated as R code.
+#' @param ... Character strings enclosed by `"{ }"` will be evaluated as R code.
 #'
-#' Character strings enclosed by \code{"<< >>"} will be printed as formatted and colored text.
+#' Character strings enclosed by `"<< >>"` will be printed as formatted and colored text.
 #'
 #' Long strings are broken by line and concatenated together.
 #'
 #' Leading whitespace and blank lines from the first and last lines are automatically trimmed.
 #'
-#' @return Formatted text.
+#' @return
+#' Formatted text.
 #'
 #' @examples
 #' name = "Bruce"
@@ -289,8 +298,8 @@ Print = function(...) {
 }
 
 
-#' @describeIn Print Paste strings.
-#'
+#' @describeIn Print
+#' Paste strings.
 #' @export
 Glue = function(...) {
   output = glue(..., .transformer=sprintf_transformer, .envir=parent.frame())
@@ -338,11 +347,11 @@ sprintf_transformer = function(text, envir) {
 
 #' Run code parsed from text.
 #'
-#' @param ... Character string(s) to run.
-#' You can use \code{"{ }"} to insert any R object in the environment.
-#' @param silent Suppress error/warning messages. Defaults to \code{FALSE}.
+#' @param ... Character string(s) to run. You can use `"{ }"` to insert any R object in the environment.
+#' @param silent Suppress error/warning messages. Defaults to `FALSE`.
 #'
-#' @return Invisibly return the running expression(s).
+#' @return
+#' Invisibly return the running expression(s).
 #'
 #' @examples
 #' Run("a=1", "b=2")
@@ -369,12 +378,13 @@ Run = function(..., silent=FALSE) {
 #'
 #' @param ... Character string(s).
 #' @param sep Pattern for separation.
-#' Defaults to \code{"auto"}:
-#' \code{,} \code{;} \code{|} \code{\\n} \code{\\t}
+#' Defaults to `"auto"`:
+#' `,` `;` `|` `\n` `\t`
 #' @param trim Remove whitespace from start and end of string(s)?
-#' Defaults to \code{TRUE}.
+#' Defaults to `TRUE`.
 #'
-#' @return Character vector.
+#' @return
+#' Character vector.
 #'
 #' @examples
 #' cc("a,b,c,d,e")
@@ -428,7 +438,8 @@ cc_m_ci = function(mean, llci, ulci, digits) {
 #' @param char Character string.
 #' @param rep.times Times for repeat.
 #'
-#' @return Character string.
+#' @return
+#' Character string.
 #'
 #' @examples
 #' rep_char("a", 5)
@@ -461,46 +472,21 @@ fct_rev = function(f) {
 
 #' Print a three-line table (to R Console and Microsoft Word).
 #'
-#' This basic function prints any data frame as a three-line table
-#' to either R Console or Microsoft Word (.doc).
-#' It has been used in many other functions of \code{bruceR} (see below).
+#' This basic function prints any data frame as a three-line table to either R Console or Microsoft Word (.doc). It has been used in many other functions of `bruceR` (see below).
 #'
-#' @param x Matrix, data.frame (or data.table), or any model object (e.g., \code{lm, glm, lmer, glmer, ...}).
-#' @param digits Numeric vector specifying the number of decimal places of output. Defaults to \code{3}.
-#' @param nspaces Number of whitespaces between columns. Defaults to \code{1}.
-#' @param row.names,col.names Print row/column names. Defaults to \code{TRUE} (column names are always printed).
-#' To modify the names, you can use a character vector with the same length as the raw names.
-#' @param title Title text, which will be inserted in <p></p> (HTML code).
-#' @param note Note text, which will be inserted in <p></p> (HTML code).
+#' @param x Matrix, data.frame (or data.table), or any model object (e.g., `lm`, `glm`, `lmer`, `glmer`, ...).
+#' @param digits Numeric vector specifying the number of decimal places of output. Defaults to `3`.
+#' @param nspaces Number of whitespaces between columns. Defaults to `1`.
+#' @param row.names,col.names Print row/column names. Defaults to `TRUE` (column names are always printed). To modify the names, you can use a character vector with the same length as the raw names.
+#' @param title Title text, which will be inserted in `<p></p>` (HTML code).
+#' @param note Note text, which will be inserted in `<p></p>` (HTML code).
 #' @param append Other contents, which will be appended in the end (HTML code).
-#' @param line Lines looks like true line (\code{TRUE}) or \code{=== --- ===} (\code{FALSE}).
-#' @param file File name of MS Word (\code{.doc}).
-#' @param file.align.head,file.align.text Alignment of table head or table text:
-#' \code{"left"}, \code{"right"}, \code{"center"}.
-#' Either one value of them OR a character vector of mixed values
-#' with the same length as the table columns.
-#' Default alignment (if set as \code{"auto"}):
-#' left, right, right, ..., right.
+#' @param line Lines looks like true line (`TRUE`) or `=== --- ===` (`FALSE`).
+#' @param file File name of MS Word (`.doc`).
+#' @param file.align.head,file.align.text Alignment of table head or table text: `"left"`, `"right"`, `"center"`. Either one value of them OR a character vector of mixed values with the same length as the table columns. Default alignment (if set as `"auto"`): left, right, right, ..., right.
 #'
-#' @return Invisibly return a list of data frame and HTML code.
-#'
-#' @seealso
-#' These functions have implemented MS Word file output using this function:
-#' \itemize{
-#'   \item \code{\link{Describe}}
-#'   \item \code{\link{Freq}}
-#'   \item \code{\link{Corr}}
-#'   \item \code{\link{EFA}} / \code{\link{PCA}}
-#'   \item \code{\link{CFA}}
-#'   \item \code{\link{TTEST}}
-#'   \item \code{\link{MANOVA}}
-#'   \item \code{\link{model_summary}}
-#'   \item \code{\link{med_summary}}
-#'   \item \code{\link{lavaan_summary}}
-#'   \item \code{\link{PROCESS}}
-#'   \item \code{\link{granger_test}}
-#'   \item \code{\link{granger_causality}}
-#' }
+#' @return
+#' Invisibly return a list of data frame and HTML code.
 #'
 #' @examples
 #' print_table(data.frame(x=1))
@@ -744,15 +730,19 @@ table th, table td {padding-left: 5px; padding-right: 5px; height: 19px;}
 #' Format "1234" to "1,234".
 #'
 #' @param x A number or numeric vector.
-#' @param mark Usually \code{","}.
+#' @param mark Usually `","`.
 #'
-#' @return Formatted character string.
+#' @return
+#' Formatted character string.
+#'
+#' @seealso
+#' [format()]
+#'
+#' [formatF()]
 #'
 #' @examples
 #' formatN(1234)
 #'
-#' @seealso \code{\link[base:format]{format}}, \code{\link{formatF}}
-#'
 #' @export
 formatN = function(x, mark=",") {
   format(x, big.mark=mark)
@@ -762,14 +752,18 @@ formatN = function(x, mark=",") {
 #' Format numeric values.
 #'
 #' @param x A number or numeric vector.
-#' @param digits Number of decimal places of output. Defaults to \code{3}.
+#' @param digits Number of decimal places of output. Defaults to `3`.
 #'
-#' @return Formatted character string.
+#' @return
+#' Formatted character string.
 #'
 #' @examples
 #' formatF(pi, 20)
 #'
-#' @seealso \code{\link[base:format]{format}}, \code{\link{formatN}}
+#' @seealso
+#' [format()]
+#'
+#' [formatN()]
 #'
 #' @export
 formatF = function(x, digits=3) {
@@ -784,17 +778,18 @@ formatF = function(x, digits=3) {
 }
 
 
-#' A simple extension of \code{rgb()}.
+#' A simple extension of [rgb()].
 #'
 #' @param r,g,b Red, Green, Blue: 0~255.
 #' @param alpha Color transparency (opacity): 0~1.
 #' If not specified, an opaque color will be generated.
 #'
-#' @return \code{"#rrggbb"} or \code{"#rrggbbaa"}.
+#' @return
+#' `"#rrggbb"` or `"#rrggbbaa"`.
 #'
 #' @examples
 #' RGB(255, 0, 0)  # red: "#FF0000"
-#' RGB(255, 0, 0, 0.8)  # red with 80\% opacity: "#FF0000CC"
+#' RGB(255, 0, 0, 0.8)  # red with 80% opacity: "#FF0000CC"
 #'
 #' @export
 RGB = function(r, g, b, alpha) {
@@ -805,10 +800,11 @@ RGB = function(r, g, b, alpha) {
 #' Timer (compute time difference).
 #'
 #' @param t0 Time at the beginning.
-#' @param unit Options: \code{"auto", "secs", "mins", "hours", "days", "weeks"}. Defaults to \code{"secs"}.
-#' @param digits Number of decimal places of output. Defaults to \code{0}.
+#' @param unit Options: `"auto"`, `"secs"`, `"mins"`, `"hours"`, `"days"`, `"weeks"`. Defaults to `"secs"`.
+#' @param digits Number of decimal places of output. Defaults to `0`.
 #'
-#' @return A character string of time difference.
+#' @return
+#' A character string of time difference.
 #'
 #' @examples
 #' \dontrun{
@@ -824,25 +820,23 @@ dtime = function(t0, unit="secs", digits=0) {
 }
 
 
-
-
 #### File I/O ####
 
 
 #' Set working directory to the path of currently opened file.
 #'
-#' Set working directory to the path of currently opened file (usually an R script).
-#' You can use this function in both \strong{.R/.Rmd files and R Console}.
-#' \href{https://posit.co/download/rstudio-desktop/}{RStudio}
+#' Set working directory to the path of currently opened file (usually an R script). You may use this function in both **.R/.Rmd files and R Console**.
+#' [RStudio](https://posit.co/download/rstudio-desktop/)
 #' (version >= 1.2) is required for running this function.
 #'
-#' @param path \code{NULL} (default) or a specific path.
-#' Defaults to extract the path of the currently opened file
-#' (usually .R or .Rmd) using the \code{rstudioapi::getSourceEditorContext} function.
-#' @param ask \code{TRUE} or \code{FALSE} (default).
-#' If \code{TRUE}, you can select a folder with the prompt of a dialog.
+#' @param path `NULL` (default) or a specific path. Defaults to extract the path of the currently opened file (usually .R or .Rmd) using the `rstudioapi::getSourceEditorContext` function.
+#' @param ask `TRUE` or `FALSE` (default). If `TRUE`, you can select a folder with the prompt of a dialog.
 #'
-#' @return Invisibly return the path.
+#' @return
+#' Invisibly return the path.
+#'
+#' @seealso
+#' [setwd()]
 #'
 #' @examples
 #' \dontrun{
@@ -854,9 +848,8 @@ dtime = function(t0, unit="secs", digits=0) {
 #'   set.wd(ask=TRUE)  # select a folder with the prompt of a dialog
 #' }
 #'
-#' @seealso \code{\link[base:getwd]{setwd}}
-#'
-#' @describeIn set.wd Main function
+#' @describeIn set.wd
+#' Main function
 #' @aliases set_wd
 #' @export
 set.wd = function(path=NULL, ask=FALSE) {
@@ -899,7 +892,8 @@ set.wd = function(path=NULL, ask=FALSE) {
 }
 
 
-#' @describeIn set.wd The alias of \code{set.wd} (the same)
+#' @describeIn set.wd
+#' The alias of `set.wd` (the same)
 #' @export
 set_wd = set.wd
 
@@ -914,65 +908,45 @@ file_ext = function(filename) {
 #' Import data from a file (TXT, CSV, Excel, SPSS, Stata, ...) or clipboard.
 #'
 #' @description
-#' Import data from a file, with format automatically judged from file extension.
-#' This function is inspired by \code{\link[rio:import]{rio::import()}}
-#' and has several modifications.
-#' Its purpose is to avoid using lots of \code{read_xxx()} functions in your code
-#' and to provide one tidy function for data import.
+#' Import data from a file, with format automatically judged from file extension. This function is inspired by [rio::import()] and has several modifications. Its purpose is to avoid using lots of `read_xxx()` functions in your code and to provide one tidy function for data import. It supports many file formats (local or URL) and uses the corresponding R functions:
 #'
-#' It supports many file formats (local or URL) and
-#' uses the corresponding R functions:
-#'
-#' \itemize{
-#'   \item Plain text (.txt, .csv, .csv2, .tsv, .psv), using \code{\link[data.table:fread]{data.table::fread()}}
-#'   \item Excel (.xls, .xlsx), using \code{\link[readxl:read_excel]{readxl::read_excel()}}
-#'   \item SPSS (.sav), using \code{\link[haven:read_spss]{haven::read_sav()}}
-#'   or \code{\link[foreign:read.spss]{foreign::read.spss()}}
-#'   \item Stata (.dta), using \code{\link[haven:read_dta]{haven::read_dta()}}
-#'   or \code{\link[foreign:read.dta]{foreign::read.dta()}}
-#'   \item R objects (.rda, .rdata, .RData), using \code{\link[base:load]{base::load()}}
-#'   \item R serialized objects (.rds), using \code{\link[base:readRDS]{base::readRDS()}}
-#'   \item Clipboard (on Windows and Mac OS), using \code{\link[clipr:read_clip_tbl]{clipr::read_clip_tbl()}}
-#'   \item Other formats, using \code{\link[rio:import]{rio::import()}}
-#' }
+#' - Plain text (.txt, .csv, .csv2, .tsv, .psv), using [data.table::fread()]
+#' - Excel (.xls, .xlsx), using [readxl::read_excel()]
+#' - SPSS (.sav), using [haven::read_sav()] or [foreign::read.spss()]
+#' - Stata (.dta), using [haven::read_dta()] or [foreign::read.dta()]
+#' - R objects (.rda, .rdata, .RData), using [load()]
+#' - R serialized objects (.rds), using [readRDS()]
+#' - Clipboard (on Windows and Mac OS), using [clipr::read_clip_tbl()]
+#' - Other formats, using [rio::import()]
 #'
 #' @param file File name (with extension).
 #' If unspecified, then data will be imported from clipboard.
-#' @param encoding File encoding. Defaults to \code{NULL}.
-#' Options: \code{"UTF-8"}, \code{"GBK"}, \code{"CP936"}, etc.
+#' @param encoding File encoding. Defaults to `NULL`.
 #'
-#' If you find messy code for Chinese text in the imported data,
-#' it is usually effective to set \code{encoding="UTF-8"}.
-#' @param header Does the first row contain column names (\code{TRUE} or \code{FALSE})?
-#' Defaults to \code{"auto"}.
-#' @param sheet [Only for Excel] Excel sheet name (or sheet number).
-#' Defaults to the first sheet.
-#' Ignored if the sheet is specified via \code{range}.
-#' @param range [Only for Excel] Excel cell range.
-#' Defaults to all cells in a sheet.
-#' You may specify it as \code{range="A1:E100"} or \code{range="Sheet1!A1:E100"}.
-#' @param pkg [Only for SPSS & Stata] Use which R package to read
-#' SPSS (.sav) or Stata (.dta) data file?
-#' Defaults to \code{"haven"}. You may also use \code{"foreign"}.
+#' Options: `"UTF-8"`, `"GBK"`, `"CP936"`, etc.
 #'
-#' Notably, \code{"haven"} may be preferred because it is more robust to
-#' non-English characters and can also keep variable labels (descriptions)
-#' from SPSS.
-#' @param value.labels [Only for SPSS & Stata] Convert variables with value labels
-#' into R factors with those levels? Defaults to \code{FALSE}.
-#' @param as Class of the imported data.
-#' Defaults to \code{"data.frame"}.
-#' Ignored if the file is an R data object (.rds, .rda, .rdata, .RData).
+#' If you find messy code for Chinese text in the imported data, it is usually effective to set `encoding="UTF-8"`.
+#' @param header Does the first row contain column names (`TRUE` or `FALSE`)? Defaults to `"auto"`.
+#' @param sheet \[Only for Excel\] Excel sheet name (or sheet number). Defaults to the first sheet. Ignored if the sheet is specified via `range`.
+#' @param range \[Only for Excel\] Excel cell range. Defaults to all cells in a sheet. You may specify it as `range="A1:E100"` or `range="Sheet1!A1:E100"`.
+#' @param pkg \[Only for SPSS & Stata\] Use which R package to read
+#' SPSS (.sav) or Stata (.dta) data file? Defaults to `"haven"`. You may also use `"foreign"`.
+#'
+#' Notably, `"haven"` may be preferred because it is more robust to non-English characters and can also keep variable labels (descriptions) from SPSS.
+#' @param value.labels \[Only for SPSS & Stata\] Convert variables with value labels into R factors with those levels? Defaults to `FALSE`.
+#' @param as Class of the imported data. Defaults to `"data.frame"`. Ignored if the file is an R data object (.rds, .rda, .rdata, .RData).
 #'
 #' Options:
-#' \itemize{
-#'   \item data.frame: \code{"data.frame"}, \code{"df"}, \code{"DF"}
-#'   \item data.table: \code{"data.table"}, \code{"dt"}, \code{"DT"}
-#'   \item tbl_df: \code{"tibble"}, \code{"tbl_df"}, \code{"tbl"}
-#' }
-#' @param verbose Print data information? Defaults to \code{FALSE}.
+#' - data.frame: `"data.frame"`, `"df"`, `"DF"`
+#' - data.table: `"data.table"`, `"dt"`, `"DT"`
+#' - tbl_df: `"tibble"`, `"tbl_df"`, `"tbl"`
+#' @param verbose Print data information? Defaults to `FALSE`.
 #'
-#' @return A data object (default class is \code{data.frame}).
+#' @return
+#' A data object (default class is `data.frame`).
+#'
+#' @seealso
+#' [export()]
 #'
 #' @examples
 #' \dontrun{
@@ -988,8 +962,6 @@ file_ext = function(filename) {
 #'   data = import("mydata.xlsx", as="data.table")
 #' }
 #'
-#' @seealso \code{\link{export}}
-#'
 #' @export
 import = function(
     file,
@@ -1121,47 +1093,38 @@ import = function(
 #' Export data to a file (TXT, CSV, Excel, SPSS, Stata, ...) or clipboard.
 #'
 #' @description
-#' Export data to a file, with format automatically judged from file extension.
-#' This function is inspired by \code{\link[rio:export]{rio::export()}}
-#' and has several modifications.
-#' Its purpose is to avoid using lots of \code{write_xxx()} functions in your code
-#' and to provide one tidy function for data export.
+#' Export data to a file, with format automatically judged from file extension. This function is inspired by [rio::export()] and has several modifications. Its purpose is to avoid using lots of `write_xxx()` functions in your code and to provide one tidy function for data export.
 #'
 #' It supports many file formats and uses corresponding R functions:
 #'
-#' \itemize{
-#'   \item Plain text (.txt, .csv, .csv2, .tsv, .psv), using \code{\link[data.table:fwrite]{data.table::fwrite()}};
-#'   if the \code{encoding} argument is specified, using \code{\link[utils:write.table]{utils::write.table()}} instead
-#'   \item Excel (.xls, .xlsx), using \code{\link[openxlsx:write.xlsx]{openxlsx::write.xlsx()}}
-#'   \item SPSS (.sav), using \code{\link[haven:read_spss]{haven::write_sav()}}
-#'   \item Stata (.dta), using \code{\link[haven:read_dta]{haven::write_dta()}}
-#'   \item R objects (.rda, .rdata, .RData), using \code{\link[base:save]{base::save()}}
-#'   \item R serialized objects (.rds), using \code{\link[base:readRDS]{base::saveRDS()}}
-#'   \item Clipboard (on Windows and Mac OS), using \code{\link[clipr:write_clip]{clipr::write_clip()}}
-#'   \item Other formats, using \code{\link[rio:export]{rio::export()}}
-#' }
+#' - Plain text (.txt, .csv, .csv2, .tsv, .psv), using [data.table::fwrite()]; if the `encoding` argument is specified, using [utils::write.table()] instead
+#' - Excel (.xls, .xlsx), using [openxlsx::write.xlsx()]
+#' - SPSS (.sav), using [haven::write_sav()]
+#' - Stata (.dta), using [haven::write_dta()]
+#' - R objects (.rda, .rdata, .RData), using [save()]
+#' - R serialized objects (.rds), using [saveRDS()]
+#' - Clipboard (on Windows and Mac OS), using [clipr::write_clip()]
+#' - Other formats, using [rio::export()]
 #'
-#' @param x Any R object, usually a data frame (\code{data.frame}, \code{data.table}, \code{tbl_df}).
-#' Multiple R objects should be included in a \emph{named} \code{list} (see examples).
+#' @param x Any R object, usually a data frame (`data.frame`, `data.table`, `tbl_df`). Multiple R objects should be included in a *named* `list` (see examples). To save R objects, specify `file` with extensions `.rda`, `.rdata`, or `.RData`.
+#' @param file File name (with extension). If unspecified, data will be exported to clipboard.
+#' @param encoding File encoding. Defaults to `NULL`.
 #'
-#' If you want to save R objects other than a data frame (e.g., model results),
-#' you'd better specify \code{file} with extensions .rda, .rdata, or .RData.
-#' @param file File name (with extension).
-#' If unspecified, then data will be exported to clipboard.
-#' @param encoding File encoding. Defaults to \code{NULL}.
-#' Options: \code{"UTF-8"}, \code{"GBK"}, \code{"CP936"}, etc.
+#' Options: `"UTF-8"`, `"GBK"`, `"CP936"`, etc.
 #'
-#' If you find messy code for Chinese text in the exported data (often in CSV when opened with Excel),
-#' it is usually useful to set \code{encoding="GBK"} or \code{encoding="CP936"}.
-#' @param header Does the first row contain column names (\code{TRUE} or \code{FALSE})? Defaults to \code{"auto"}.
-#' @param sheet [Only for Excel] Excel sheet name(s).
-#' Defaults to "Sheet1", "Sheet2", ...
-#' You may specify multiple sheet names in a character vector
-#' \code{c()} with the \emph{same length} as \code{x} (see examples).
-#' @param overwrite Overwrite the existing file (if any)? Defaults to \code{TRUE}.
-#' @param verbose Print output information? Defaults to \code{FALSE}.
+#' If you find messy code for Chinese text in the exported data (often in CSV when opened with Excel), it is usually useful to set `encoding="GBK"` or `encoding="CP936"`.
+#' @param header Does the first row contain column names (`TRUE` or `FALSE`)? Defaults to `"auto"`.
+#' @param sheet \[Only for Excel\] Excel sheet name(s). Defaults to "Sheet1", "Sheet2", ... You may specify multiple sheet names in a character vector `c()` with the *same length* as `x` (see examples).
+#' @param overwrite Overwrite the existing file (if any)? Defaults to `TRUE`.
+#' @param verbose Print output information? Defaults to `FALSE`.
 #'
-#' @return No return value.
+#' @return
+#' No return value.
+#'
+#' @seealso
+#' [import()]
+#'
+#' [print_table()]
 #'
 #' @examples
 #' \dontrun{
@@ -1187,8 +1150,6 @@ import = function(
 #'   load("lm_npk.Rdata")  # because x is named, the object has a name "m1"
 #' }
 #'
-#' @seealso \code{\link{import}}, \code{\link{print_table}}
-#'
 #' @export
 export = function(
     x, file,
@@ -1344,34 +1305,25 @@ restore_labelled = function(x) {
 }
 
 
-
-
 #### Excel-Style Functions ####
 
 
-#' Search, match, and look up values (like Excel's functions \code{INDEX + MATCH}).
+#' Search, match, and look up values (like Excel's functions `INDEX + MATCH`).
 #'
-#' In Excel, we can use \code{VLOOKUP}, \code{HLOOKUP}, \code{XLOOKUP} (a new function released in 2019),
-#' or the combination of \code{INDEX} and \code{MATCH} to search, match, and look up values.
-#' Here I provide a similar function.
-#'
-#' If multiple values were simultaneously matched, a warning message would be printed.
+#' In Excel, we can use `VLOOKUP`, `HLOOKUP`, `XLOOKUP` (a new function released in 2019), or the combination of `INDEX` and `MATCH` to search, match, and look up values. Here I provide a similar function. If multiple values were simultaneously matched, a warning message would be printed.
 #'
 #' @param data Main data.
-#' @param vars Character (vector), specifying the variable(s) to be searched in \code{data}.
+#' @param vars Character (vector), specifying the variable(s) to be searched in `data`.
 #' @param data.ref Reference data containing both the reference variable(s) and the lookup variable(s).
-#' @param vars.ref Character (vector), with the \strong{same length and order} as \code{vars},
-#' specifying the reference variable(s) to be matched in \code{data.ref}.
-#' @param vars.lookup Character (vector), specifying the variable(s) to be looked up and returned from \code{data.ref}.
-#' @param return What to return. Default (\code{"new.data"}) is to return a data frame with the lookup values added.
-#' You may also set it to \code{"new.var"} or \code{"new.value"}.
+#' @param vars.ref Character (vector), with the **same length and order** as `vars`, specifying the reference variable(s) to be matched in `data.ref`.
+#' @param vars.lookup Character (vector), specifying the variable(s) to be looked up and returned from `data.ref`.
+#' @param return What to return. Default (`"new.data"`) is to return a data frame with the lookup values added. You may also set it to `"new.var"` or `"new.value"`.
 #'
-#' @return New data object, new variable, or new value (see the argument \code{return}).
+#' @return
+#' New data object, new variable, or new value (see the argument `return`).
 #'
 #' @seealso
-#' \code{\link[dplyr:mutate-joins]{dplyr::left_join()}}
-#'
-#' \href{https://www.excel-university.com/xlookup/}{XLOOKUP: Excel University}
+#' [dplyr::left_join()]
 #'
 #' @examples
 #' ref = data.table(City=rep(c("A", "B", "C"), each=5),
@@ -1389,10 +1341,12 @@ restore_labelled = function(x) {
 #' LOOKUP(data, c("city", "year"), ref, c("City", "Year"), c("GDP", "PM2.5"))
 #'
 #' @export
-LOOKUP = function(data, vars,
-                  data.ref, vars.ref,
-                  vars.lookup,
-                  return=c("new.data", "new.var", "new.value")) {
+LOOKUP = function(
+    data, vars,
+    data.ref, vars.ref,
+    vars.lookup,
+    return=c("new.data", "new.var", "new.value")
+) {
   by = vars.ref
   names(by) = vars
   data.ref = as.data.frame(data.ref)
